import pytest
from mockito import when

from . import module


@pytest.mark.usefixtures('unstub')
class TestIssue82:
    def testFunctionWithArgumentNamedValue(self):
        when(module).send(value="test").thenReturn("nope")
        assert module.send(value="test") == "nope"




import pytest
from mockito import when


class Data:
    def __init__(self, name):
        self.name = name

    def __eq__(self, other):
        if isinstance(other, Data):
            return self.name == other.name
        return NotImplemented

    def tell_name(self):
        return self.name


@pytest.mark.usefixtures('unstub')
class TestIssue86:
    def testValueObjectsAreTreatedByIdentity(self):
        a = Data("Bob")
        b = Data("Bob")
        when(a).tell_name().thenReturn("Sarah")
        when(b).tell_name().thenReturn("Mulder")
        assert a.tell_name() == "Sarah"
        assert b.tell_name() == "Mulder"





from mockito.mock_registry import IdentityMap


class TestIdentityMap:

    def testSetItemIsImplemented(self):
        td = IdentityMap()
        key = object()
        val = object()
        td[key] = val

    def testGetValueForKey(self):
        td = IdentityMap()
        key = object()
        val = object()
        td[key] = val

        assert td.get(key) == val
        assert td.get(object(), 42) == 42

    def testReplaceValueForSameKey(self):
        td = IdentityMap()
        key = object()
        mock1 = object()
        mock2 = object()
        td[key] = mock1
        td[key] = mock2

        assert td.values() == [mock2]

    def testPopKey(self):
        td = IdentityMap()
        key = object()
        val = object()
        td[key] = val

        assert td.pop(key) == val
        assert td.values() == []

    def testClear(self):
        td = IdentityMap()
        key = object()
        val = object()
        td[key] = val

        td.clear()
        assert td.values() == []

    def testEqualityIsIgnored(self):
        td = IdentityMap()
        td[{"one", "two", "foo"}] = object()
        td[{"one", "two", "foo"}] = object()
        assert len(td.values()) == 2



from setuptools import setup

import re
import ast


_version_re = re.compile(r'__version__\s+=\s+(.*)')

with open('mockito/__init__.py', 'rb') as f:
    version = str(ast.literal_eval(_version_re.search(
        f.read().decode('utf-8')).group(1)))


setup(name='mockito',
      version=version,
      packages=['mockito'],
      url='https://github.com/kaste/mockito-python',
      maintainer='herr.kaste',
      maintainer_email='herr.kaste@gmail.com',
      license='MIT',
      description='Spying framework',
      long_description=open('README.rst').read(),
      python_requires='>=3.7',
      classifiers=[
          'Development Status :: 5 - Production/Stable',
          'Intended Audience :: Developers',
          'License :: OSI Approved :: MIT License',
          'Topic :: Software Development :: Testing',
          'Programming Language :: Python :: 3',
          'Programming Language :: Python :: 3.7',
          'Programming Language :: Python :: 3.8',
          'Programming Language :: Python :: 3.9',
          'Programming Language :: Python :: 3.10',
          'Programming Language :: Python :: 3.11',
          'Programming Language :: Python :: 3.12',
      ])
